ToastPosition enum

Toast position options

Inheritance
Available extensions

Values

topLeft → const ToastPosition

Top left corner

topCenter → const ToastPosition

Top center

topRight → const ToastPosition

Top right corner

centerLeft → const ToastPosition

Center left

center → const ToastPosition

Center of screen

centerRight → const ToastPosition

Center right

bottomLeft → const ToastPosition

Bottom left corner

bottomCenter → const ToastPosition

Bottom center

bottomRight → const ToastPosition

Bottom right corner

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ToastPosition>
A constant List of the values in this enum, in order of their declaration.