ToastType enum

Toast type with predefined colors and icons

Inheritance
Available extensions

Values

success → const ToastType

Success type with green color and check icon

const ToastType(Color(0xFF4CAF50), Icons.check_circle)
error → const ToastType

Error type with red color and error icon

const ToastType(Color(0xFFF44336), Icons.error)
warning → const ToastType

Warning type with orange color and warning icon

const ToastType(Color(0xFFFF9800), Icons.warning)
info → const ToastType

Info type with blue color and info icon

const ToastType(Color(0xFF2196F3), Icons.info)

Properties

color Color
Default background color for this toast type
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
Default icon for this toast type
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ToastType>
A constant List of the values in this enum, in order of their declaration.